Module: Merb::AssetsMixin

Includes:
Merb::Assets::AssetHelpers
Defined in:
lib/merb-assets/assets_mixin.rb

Overview

The AssetsMixin module provides a number of helper methods to views for linking to assets and other pages, dealing with JavaScript and CSS.

Merb provides views with convenience methods for links images and other assets.

Constant Summary collapse

ABSOLUTE_PATH_REGEXP =
%r{^#{Merb::Const::HTTP}s?://}

Constants included from Merb::Assets::AssetHelpers

Merb::Assets::AssetHelpers::ASSET_FILE_EXTENSIONS

Class Method Summary collapse

Instance Method Summary collapse